<!-- PROJECT: AUTO-GENERATED DOCS START (do not remove) -->

# 🪐 项目: nlu模型推理框架

基于entry point的nlu多后端模型推理框架

## 📋 project.yml

[`project.yml`](project.yml)定义了项目所有的命令以及由命令组成的流程. 

### ⏯ 命令

以下是项目中的命令. 它们都可以通过`project run [name]`来运行.

| 命令 | 描述 |
| --- | --- |
| `publish` | 发布到普强源 |

<!-- PROJECT: AUTO-GENERATED DOCS END (do not remove) -->

### 📦 安装

```bash
pip install nlu-inference --upgrade
```

```bash
pip install nlu-inference --upgrade -i http://192.168.130.5:5002/simple/ --trusted-host 192.168.130.5 --extra-index-url https://mirrors.aliyun.com/pypi/simple

```

### 🚀 使用

```bash
nlu-inference --help
```